@@ -54,6 +54,7 @@ pub struct WsConnect<T, M = Simple> {
 }
 
 impl<T> WsConnect<T> {
+    #[inline]
     pub const fn new(conn: T, conf: WsConf) -> Self {
         Self {
             conn,
@@ -62,6 +63,7 @@ impl<T> WsConnect<T> {
         }
     }
 
+    #[inline]
     pub fn standard(self) -> WsConnect<T, Standard> {
         WsConnect {
             conn: self.conn,
@@ -69,6 +71,15 @@ impl<T> WsConnect<T> {
             _marker: PhantomData,
         }
     }
+
+    #[inline]
+    pub fn fixed(self) -> WsConnect<T, Fixed> {
+        WsConnect {
+            conn: self.conn,
+            conf: self.conf,
+            _marker: PhantomData,
+        }
+    }
 }
 
 impl<S, T, M: Mode> AsyncConnect<S> for WsConnect<T, M>
@@ -93,7 +104,6 @@ where
             )
             .await?
             .guard();
-
             Ok(stream)
         }
     }
@@ -107,6 +117,7 @@ pub struct WsAccept<T> {
 }
 
 impl<T> WsAccept<T> {
+    #[inline]
     pub const fn new(lis: T, conf: WsConf) -> Self { Self { lis, conf } }
 }
 
